Learn R Programming

TVMVP (version 1.0.5)

sqrt_matrix: Compute the Square Root of a Matrix

Description

Computes the square root of a symmetric matrix via eigen decomposition. Negative eigenvalues are handled by taking the square root of their absolute values.

Usage

sqrt_matrix(Amat)

Value

A matrix that is the square root of Amat.

Arguments

Amat

A numeric symmetric matrix.