powered by
Computes the square root of a symmetric matrix via eigen decomposition. Negative eigenvalues are handled by taking the square root of their absolute values.
sqrt_matrix(Amat)
A matrix that is the square root of Amat.
Amat
A numeric symmetric matrix.